@@ -1,3 +1,5 @@
+from typing import Any
+
 from django.core.exceptions import ObjectDoesNotExist
 from edc_fieldsets import FieldsetsModelAdminMixin
 from edc_visit_tracking.modeladmin_mixins import CrfModelAdminMixin
@@ -22,14 +24,14 @@ class ModelAdminCrfDashboardMixin(
             appointment=str(obj.subject_visit.appointment.id),
         )
 
-    def get_changeform_initial_data(self, request):
-        initial_data = super().get_changeform_initial_data(request)
+    def get_changeform_initial_data(self: Any, request) -> dict:
+        initial_data = super().get_changeform_initial_data(request)  # noqa
         try:
             subject_visit = get_subject_visit_model_cls().objects.get(
                 id=request.GET.get(self.model.visit_model_attr())
             )
         except ObjectDoesNotExist:
-            # TODO: how do we get here?
+            # TODO: how do we get here? PRN?
             pass
         else:
             initial_data.update(
